Credits — AIscalator 0.1.0 documentation

### Navigation

- ☰
- AIscalator-0.1.0 »

Fork me on GitHub

# Credits

## Development Lead

- Christophe Duong <chris@aiscalate.com>

## Contributors

None yet. Why not be the first?

## Components

This software uses the following open source components:

- Jupyter-Project notebook, lab, etc under BSD-3-Clause license
- Jupytext under MIT license
- Docker
- Jupyter-Docker-Stacks under BSD-3-Clause license
- Airflow under Apache-2 license
- Docker-Airflow under Apache-2 license
- Papermill under BSD-3-Clause license
- This project was created with Cookiecutter under BSD-3-Clause license
- with the audreyr/cookiecutter-pypackage project template.
- with the ionelmc/cookiecutter-pylibrary project template
- PyHOCON under Apache-2 license

### Navigation

- index
- modules |
- next |
- previous |